---
title: ode
sidebarTitle: ode
---

# `catalax.model.ode`

## Classes

### `ODE` <sup><a href="https://github.com/JR-1991/Catalax/blob/master/catalax/model/ode.py#L9" target="_blank"><Icon icon="github" style="width: 14px; height: 14px;" /></a></sup>
